@@ -3,21 +3,20 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 
 #' @title Plot beta coefficients of multiple fitted lm's
 #' @name sjp.lmm
-#' @references \url{http://strengejacke.wordpress.com/sjplot-r-package/}
 #' 
 #' @description Plot beta coefficients (estimates) with confidence intervalls of multiple fitted linear models
 #'                in one plot.
 #'                
-#' @seealso \code{\link{sjp.lm}} \cr
-#'          \code{\link{sjt.lm}} \cr
-#'          \code{\link{sjp.lm.ma}} \cr
-#'          \code{\link{sjp.glmm}}
+#' @seealso \itemize{
+#'            \item \code{\link{sjp.lm}}
+#'            \item \code{\link{sjt.lm}}
+#'            \item \code{\link{sjp.lm.ma}}
+#'            \item \code{\link{sjp.glmm}}
+#'            }
 #' 
 #' @param ... One or more fitted lm-objects.
 #' @param title Diagram's title as string.
 #'          Example: \code{title=c("my title")}
-#' @param titleSize The size of the plot title. Default is 1.3.
-#' @param titleColor The color of the plot title. Default is \code{"black"}.
 #' @param labelDependentVariables Labels of the dependent variables of all fitted models
 #'          which have been used as first parameter(s), provided as char vector.
 #' @param legendDepVarTitle A character vector used for the title of the dependent variable's legend.
@@ -33,20 +32,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getValueLabels}} function, you receive a
 #'          \code{list} object with label strings. The labels may also be passed as list object. They will be unlisted and
 #'          converted to character vector automatically.
-#' @param axisLabelSize The size of value labels in the diagram. Default is 1.1, recommended values range
-#'          between 0.7 and 3.0
 #' @param showAxisLabels.y Whether beta names (predictor labels) should be shown or not.
-#' @param showTickMarks Whether tick marks of axes should be shown or not.
 #' @param axisTitle.x A label ("title") for the x axis.
-#' @param axisTitleColor The color of the x axis label.
-#' @param axisTitleSize The size of the x axis label.
 #' @param axisLimits Defines the range of the axis where the beta coefficients and their confidence intervalls
 #'          are drawn. By default, the limits range from the lowest confidence interval to the highest one, so
 #'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits=c(-0.8,0.8)}.
-#' @param axisLabelAngle.x Angle for axis-labels where the estimates labels are printed. Note
-#'          that due to the coordinate flip, the acutal y-axis with estimates are appearing on the x-axis.
-#' @param axisLabelAngle.y Angle for axis-labels where the predictor labels (\code{axisLabels.y}) are printed. Note
-#'          that due to the coordinate flip, the acutal x-axis with predictor labels are appearing on the y-axis.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
 #'          one line and when a line break is inserted into the title
 #' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
@@ -56,64 +46,28 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'          is displayed in one line in the legend and when a line break is inserted
 #' @param gridBreaksAt Sets the breaks on the y axis, i.e. at every n'th position a major
 #'          grid is being printed. Default is \code{NULL}, so \code{\link{pretty}} gridbeaks will be used.
-#' @param pointSize The size of the points that indicate the beta-value. Default is 3.
-#' @param modelPlotSpace Defines the space between the dots and error bars of the plotted fitted models. Default
+#' @param geom.size The size of the points that indicate the estimates. Default is 3.
+#' @param geom.spacing Defines the space between the dots and error bars of the plotted fitted models. Default
 #'          is 0.3.
-#' @param modelColors A vector with colors for representing the beta values (i.e. points and error bars)
+#' @param geom.colors A vector with colors for representing the estimates (i.e. points and error bars)
 #'          of the different fitted models. Thus, the length of this vector must be equal to
 #'          the length of supplied fitted models, so each model is represented by its own color.
 #'          You can use:
 #'          \itemize{
-#'            \item \code{"bw"} or \code{"black"} for only one colouring in almost black
-#'            \item \code{"gray"}, \code{"grey"} or \code{"gs"} for a grayscale
-#'            \item \code{"brewer"} for colours from the color brewer palette.
+#'            \item If not specified, the qualitative \code{"Dark2"} color brewer palette will be used.
+#'            \item If \code{"gs"}, a greyscale will be used.
+#'            \item If \code{geom.colors} is any valid color brewer palette name, the related \href{http://colorbrewer2.org}{color brewer} palette will be used. Use \code{display.brewer.all()} from the \code{RColorBrewer} package to view all available palette names.
 #'            }
-#'          If \code{modelColors} is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the \url{http://colorbrewer2.org}.
-#'          Else specify your own color values as vector (e.g. \code{modelColors=c("#f00000", "#00ff00")}).
-#' @param colorPalette If parameter \code{modelColors} is \code{brewer}, specify a color palette from the \url{http://colorbrewer2.org} here.
-#'          All color brewer palettes supported by ggplot are accepted here.
-#' @param axisLabelColor Colour of the tick labels at the axis (variable names, beta names).
-#' @param valueLabelColor The colour of the beta values. These values are printed above the plots respectively beside the
-#'          bar charts. default color is \code{"black"}.
-#' @param valueLabelSize Size of the value labels. Drfault is 4. Recommended Values range from
-#'          2 to 8
-#' @param valueLabelAlpha The alpha level (transparancy) of the value labels. Default is 1, use
-#'          any value from 0 to 1.
+#'          Else specify your own color values as vector (e.g. \code{geom.colors=c("#f00000", "#00ff00", "#0080ff")}).
 #' @param nsAlpha The alpha level (transparancy) of non significant predicors. Points and error bars
 #'          are affected by this value and plotted with a slight transparancy. Default is 1.
 #' @param usePShapes If \code{TRUE}, significant levels are distinguished by different point shapes and a related
 #'          legend is plotted. Default is \code{FALSE}.
-#' @param axisColor User defined color of axis border (y- and x-axis, in case the axes should have different colors than
-#'          the diagram border).
-#' @param borderColor User defined color of whole diagram border (panel border).
 #' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
 #' @param interceptLineColor The color of the intercept line. Default value is \code{"grey70"}.
-#' @param errorBarWidth The width of the error bar ends. Default is \code{0}
-#' @param errorBarSize The size (thickness) of the error bars. Default is \code{0.5}
-#' @param errorBarLineType The linetype of error bars. Default is \code{1} (solid line).
-#' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
-#' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
-#' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param theme Specifies the diagram's background theme. Default (parameter \code{NULL}) is a gray 
-#'          background with white grids.
-#'          \itemize{
-#'          \item Use \code{"bw"} for a white background with gray grids
-#'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
-#'          \item \code{"none"} for no borders, grids and ticks or
-#'          \item \code{"themr"} if you are using the \code{ggthemr} package
-#'          }
-#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
-#' @param flipCoordinates If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
+#' @param hideLegend Indicates whether legend (guide) should be shown or not.
+#' @param coord.flip If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
 #'          values are plotted on the x-axis.
-#' @param legendPos The position of the legend, if a legend is drawn. Use \code{"bottom"}, \code{"top"}, \code{"left"}
-#'          or \code{"right"} to position the legend above, below, on the left or right side of the diagram. Right
-#'          positioning is default.
-#' @param legendSize The text size of the legend. Default is 1. Relative size, so recommended values are from 0.3 to
-#'          2.5
-#' @param legendBorderColor Color of the legend's border. Default is \code{"white"}, so no visible border is drawn.
-#' @param legendBackColor Fill color of the legend's background. Default is \code{"white"}, so no visible background is drawn.
 #' @param showIntercept If \code{TRUE}, the intercept of the fitted model is also plotted.
 #'          Default is \code{FALSE}.
 #' @param showValueLabels Whether the beta value labels should be plotted.
@@ -121,7 +75,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #'          Default is 2, i.e. estimators have 2 digits after decimal point.
 #' @param showPValueLabels Whether the significance levels of each coefficient should be appended
 #'          to values or not.
-#' @param useFacetGrid \code{TRUE} when each model should be plotted as single facet instead of 
+#' @param facet.grid \code{TRUE} when each model should be plotted as single facet instead of 
 #'          an integrated single graph.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
@@ -142,7 +96,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' fit3 <- lm(tot_sc_e ~ c160age + c12hour + c161sex + c172code, data=efc)
 #' 
 #' # plot multiple models
-#' sjp.lmm(fit1, fit2, fit3, useFacetGrid=TRUE)
+#' sjp.lmm(fit1, fit2, fit3, facet.grid=TRUE)
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.lmm(fit1, fit2, fit3,
@@ -158,58 +112,32 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' @export
 sjp.lmm <- function(..., 
                      title=NULL,
-                     titleSize=1.3,
-                     titleColor="black",
                      labelDependentVariables=NULL, 
                      legendDepVarTitle="Dependent Variables",
                      legendPValTitle="p-level",
                      stringModel="Model",
                      axisLabels.y=NULL, 
-                     axisLabelSize=1.1,
-                     axisLabelAngle.x=0, 
-                     axisLabelAngle.y=0, 
-                     axisLabelColor="gray30", 
                      axisTitle.x="Estimates",
-                     axisTitleSize=1.2,
-                     axisTitleColor=c("#444444"),
                      axisLimits=NULL,
                      breakTitleAt=50, 
-                     breakLabelsAt=12,
+                     breakLabelsAt=25,
                      breakLegendAt=20,
                      gridBreaksAt=NULL,
-                     errorBarWidth=0,
-                     errorBarSize=0.5,
-                     errorBarLineType=1,
-                     pointSize=3,
-                     modelPlotSpace=0.4,
-                     colorPalette="Paired",
-                     modelColors=NULL,
-                     valueLabelColor="black",
-                     valueLabelSize=4,
-                     valueLabelAlpha=1,
+                     geom.size=3,
+                     geom.spacing=0.4,
+                     geom.colors="Dark2",
                      nsAlpha=1,
                      usePShapes=FALSE,
-                     axisColor=NULL, 
-                     borderColor=NULL, 
                      interceptLineType=2,
                      interceptLineColor="grey70",
-                     majorGridColor=NULL,
-                     minorGridColor=NULL,
-                     hideGrid.x=FALSE,
-                     hideGrid.y=FALSE,
-                     theme=NULL,
-                     flipCoordinates=TRUE,
-                     legendPos="right",
-                     legendSize=1,
-                     legendBorderColor="white",
-                     legendBackColor="white",
+                     coord.flip=TRUE,
                      showIntercept=FALSE,
                      showAxisLabels.y=TRUE,
-                     showTickMarks=TRUE,
                      showValueLabels=TRUE, 
                      labelDigits=2,
                      showPValueLabels=TRUE,
-                     useFacetGrid=FALSE,
+                     hideLegend=FALSE,                    
+                     facet.grid=FALSE,
                      printPlot=TRUE) {
   # --------------------------------------------------------
   # retrieve list of fitted models
@@ -395,83 +323,6 @@ sjp.lmm <- function(...,
   else {
     ticks <- c(seq(lower_lim, upper_lim, by=gridBreaksAt))
   }
-  # --------------------------------------------------------
-  # define bar / line colors
-  # --------------------------------------------------------
-  # check whether modelColors is defined
-  if (is.null(modelColors)) {
-    # define default colours. we use a diverging palette here,
-    # because the different models are not "sequential"
-    barcols <- brewer_pal(type="div", palette="Dark2")(fitlength)
-  }
-  else {
-    # if we have b/w colors, i.e. no differentiation between betas > 1 and < 1,
-    # we simply set both colors for betas lower and greater than 1 to the same color-value
-    if (modelColors=="bw" || modelColors=="black") {
-      barcols <- rep(c("#333333"), times=fitlength)
-    }
-    # grey-scale colors
-    else if (modelColors=="gray" || modelColors=="grey" || modelColors=="gs") {
-      barcols <- brewer_pal(palette="Greys")(fitlength)
-    }
-    else {
-      # else, use user-colors
-      barcols <- modelColors
-    }
-  }
-  # check whether we have brewer color scale
-  if (!is.null(modelColors) && modelColors=="brewer") {
-    # remember to specify the "colorPalette" if you use "brewer" as "oddsColorss"
-    scalecolors <- scale_colour_brewer(palette=colorPalette, labels=labelDependentVariables)
-  }
-  else {
-    scalecolors <- scale_colour_manual(values=barcols, labels=labelDependentVariables)
-  }
-  # --------------------------------------------------------
-  # Set theme and default grid colours. grid colours
-  # might be adjusted later
-  # --------------------------------------------------------
-  hideGridColor <- c("white")
-  if (is.null(theme)) {
-    ggtheme <- theme_gray()
-    hideGridColor <- c("gray90")
-  }
-  else if (theme=="themr") {
-    ggtheme <- NULL
-  }
-  else if (theme=="bw") {
-    ggtheme <- theme_bw()
-  }
-  else if (theme=="classic") {
-    ggtheme <- theme_classic()
-  }
-  else if (theme=="minimal") {
-    ggtheme <- theme_minimal()
-  }
-  else if (theme=="none") {
-    ggtheme <- theme_minimal()
-    majorGridColor <- c("white")
-    minorGridColor <- c("white")
-    showTickMarks <-FALSE
-  }
-  # --------------------------------------------------------
-  # Set up grid colours
-  # --------------------------------------------------------
-  majorgrid <- NULL
-  minorgrid <- NULL
-  if (!is.null(majorGridColor)) {
-    majorgrid <- element_line(colour=majorGridColor)
-  }
-  if (!is.null(minorGridColor)) {
-    minorgrid <- element_line(colour=minorGridColor)
-  }
-  hidegrid <- element_line(colour=hideGridColor)
-  # --------------------------------------------------------
-  # Set up visibility oftick marks
-  # --------------------------------------------------------
-  if (!showTickMarks && !is.null(ggtheme)) {
-    ggtheme <- ggtheme + theme(axis.ticks = element_blank())
-  }
   if (!showAxisLabels.y) {
     axisLabels.y <- c("")
   }
@@ -495,94 +346,64 @@ sjp.lmm <- function(...,
       # The order of aesthetics matters in terms of ordering the error bars!
       # Using shape before colour would order points according to shapes instead
       # of colour-aes.
-      geom_point(aes(y=beta, x=xpos, colour=grp, shape=shape), size=pointSize, position=position_dodge(-modelPlotSpace)) +
+      geom_point(aes(y=beta, x=xpos, colour=grp, shape=shape), size=geom.size, position=position_dodge(-geom.spacing)) +
       # and use a shape scale, in order to have a legend
       scale_shape_manual(values=c(1,16,17,15), labels=c("n.s.", "*", "**", "***"))
   }
   else {
     plotHeader <- plotHeader +
-      geom_point(size=pointSize, position=position_dodge(-modelPlotSpace))
+      geom_point(size=geom.size, position=position_dodge(-geom.spacing))
   }
   # --------------------------------------------------------
   # continue with errorbars, p-value-label and intercept line
   # --------------------------------------------------------
   plotHeader <- plotHeader +
+    # --------------------------------------------------------
     # print confidence intervalls (error bars)
-    geom_errorbar(aes(ymin=lower, ymax=upper), position=position_dodge(-modelPlotSpace), width=errorBarWidth, size=errorBarSize, linetype=errorBarLineType) +
+    # --------------------------------------------------------
+    geom_errorbar(aes(ymin = lower, ymax = upper), 
+                  position = position_dodge(-geom.spacing), 
+                  width = 0) +
+    # --------------------------------------------------------
     # print value labels and p-values
-    geom_text(aes(label=p, y=upper), size=valueLabelSize, position=position_dodge(width=-modelPlotSpace), hjust=-0.1) +
+    # --------------------------------------------------------
+    geom_text(aes(label = p, y = upper), 
+              position = position_dodge(width = -geom.spacing), 
+              hjust = -0.1) +
+    # --------------------------------------------------------
     # Intercept-line
-    geom_hline(yintercept=0, linetype=interceptLineType, color=interceptLineColor) +
-    labs(title=title, x=NULL, y=axisTitle.x, shape=legendPValTitle, colour=legendDepVarTitle) +
-    scale_x_discrete(labels=axisLabels.y) +
-    scale_y_continuous(limits=c(lower_lim, upper_lim), breaks=ticks, labels=ticks) +
-    # add colour legend to indicate different fitted models
-    scalecolors +
+    # --------------------------------------------------------
+    geom_hline(yintercept = 0, 
+               linetype = interceptLineType, 
+               color = interceptLineColor) +
+    labs(title = title, 
+         x = NULL, 
+         y = axisTitle.x, 
+         shape = legendPValTitle, 
+         colour = legendDepVarTitle) +
+    scale_x_discrete(labels = axisLabels.y) +
+    scale_y_continuous(limits = c(lower_lim, upper_lim), 
+                       breaks = ticks, 
+                       labels = ticks) +
+    # --------------------------------------------------------
     # use transparancy if requested, but hide legend
-    scale_alpha_manual(values=c(nsAlpha,1.0), guide="none")
-  # --------------------------------------------------------
-  # apply theme
-  # --------------------------------------------------------
-  if (!is.null(ggtheme)) {
-    plotHeader <- plotHeader +
-      ggtheme +
-      # --------------------------------------------------------
-      # set axes text and label position etc.
-      # --------------------------------------------------------
-      theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
-          axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-          axis.text.x = element_text(angle=axisLabelAngle.x),
-          axis.text.y = element_text(angle=axisLabelAngle.y),
-          plot.title = element_text(size=rel(titleSize), colour=titleColor),
-          legend.position = legendPos,
-          legend.text = element_text(size=rel(legendSize)),
-          legend.background = element_rect(colour=legendBorderColor, fill=legendBackColor))
-  }
+    # --------------------------------------------------------
+    scale_alpha_manual(values = c(nsAlpha, 1.0), guide = "none")
   # --------------------------------------------------------
   # flip coordinates?
   # --------------------------------------------------------
-  if (flipCoordinates)  {
+  if (coord.flip)  {
     plotHeader <- plotHeader +
       coord_flip()
   }
-  # --------------------------------------------------------
-  # set border colors
-  # --------------------------------------------------------
-  if (!is.null(borderColor)) {
-    if (!is.null(theme) && theme=="bw") {
-      plotHeader <- plotHeader + 
-        theme(panel.border = element_rect(colour=borderColor))
-    }
-    else {
-      cat("\nParameter 'borderColor' can only be applied to 'bw' theme.\n")
-    }
-  }
-  if (!is.null(axisColor)) {
-    plotHeader <- plotHeader + 
-      theme(axis.line = element_line(colour=axisColor))
-  }
-  if (!is.null(minorgrid)) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.minor = minorgrid)
-  }
-  if (!is.null(majorgrid)) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major = majorgrid)
-  }
-  if (hideGrid.x) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major.x = hidegrid,
-            panel.grid.minor.x = hidegrid)
-  }
-  if (hideGrid.y) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major.y = hidegrid,
-            panel.grid.minor.y = hidegrid)
-  }
-  if (useFacetGrid) {
+  if (facet.grid) {
     plotHeader <- plotHeader + facet_grid(.~grp)
   }
   # ---------------------------------------------------------
+  # set geom colors
+  # ---------------------------------------------------------
+  plotHeader <- sj.setGeomColors(plotHeader, geom.colors, length(labelDependentVariables), ifelse(hideLegend==TRUE, FALSE, TRUE), labelDependentVariables)  
+  # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
   if (printPlot) plot(plotHeader)
