@@ -3,22 +3,19 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 
 #' @title Plot odds ratios (forest plots) of multiple fitted glm's
 #' @name sjp.glmm
-#' @references \itemize{
-#'              \item \url{http://strengejacke.wordpress.com/sjplot-r-package/}
-#'              \item \url{http://strengejacke.wordpress.com/2014/01/29/comparing-multiple-glm-in-one-graph-rstats/}
-#'             }
 #' 
 #' @description Plot odds ratios (forest plots) of multiple fitted glm's with confidence intervalls in one plot.
-#' @seealso \code{\link{sjp.glm}} \cr
-#'          \code{\link{sjt.glm}} \cr
-#'          \code{\link{sjp.glm.ma}} \cr
-#'          \code{\link{sjp.lmm}}
+#' 
+#' @seealso \itemize{
+#'            \item \code{\link{sjp.glm}}
+#'            \item \code{\link{sjt.glm}}
+#'            \item \code{\link{sjp.glm.ma}}
+#'            \item \code{\link{sjp.lmm}}
+#'            }
 #' 
 #' @param ... One or more fitted glm-objects.
 #' @param title Diagram's title as string.
 #'          Example: \code{title=c("my title")}
-#' @param titleSize The size of the plot title. Default is 1.3.
-#' @param titleColor The color of the plot title. Default is \code{"black"}.
 #' @param labelDependentVariables Labels of the dependent variables of all fitted models
 #'          which have been used as first parameter(s), provided as char vector.
 #' @param legendDepVarTitle A character vector used for the title of the dependent variable's legend.
@@ -34,20 +31,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'          Note: If you use the \code{\link{sji.SPSS}} function and the \code{\link{sji.getValueLabels}} function, you receive a
 #'          \code{list} object with label strings. The labels may also be passed as list object. They will be unlisted and
 #'          converted to character vector automatically.
-#' @param axisLabelSize The size of value labels in the diagram. Default is 1.1, recommended values range
-#'          between 0.7 and 3.0
 #' @param showAxisLabels.y Whether odds names (predictor labels) should be shown or not.
-#' @param showTickMarks Whether tick marks of axes should be shown or not.
 #' @param axisTitle.x A label ("title") for the x axis.
-#' @param axisTitleColor The color of the x axis label.
-#' @param axisTitleSize The size of the x axis label.
 #' @param axisLimits Defines the range of the axis where the beta coefficients and their confidence intervalls
 #'          are drawn. By default, the limits range from the lowest confidence interval to the highest one, so
 #'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits=c(-0.8,0.8)}.
-#' @param axisLabelAngle.x Angle for axis-labels where the odds ratios are printed. Note
-#'          that due to the coordinate flip, the acutal y-axis with odds ratios are appearing on the x-axis.
-#' @param axisLabelAngle.y Angle for axis-labels where the predictor labels (\code{axisLabels.y}) are printed. Note
-#'          that due to the coordinate flip, the acutal x-axis with predictor labels are appearing on the y-axis.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
 #'          one line and when a line break is inserted into the title
 #' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
@@ -61,64 +49,28 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'          visually have the same distance from one grid bar to the next. Default is \code{FALSE} which
 #'          means that grids are plotted on every \code{gridBreaksAt}'s position, thus the grid bars
 #'          become narrower with higher odds ratio values.
-#' @param pointSize The size of the points that indicate the beta-value. Default is 3.
-#' @param modelPlotSpace Defines the space between the dots and error bars of the plotted fitted models. Default
+#' @param geom.size The size of the points that indicate the odds ratios. Default is 3.
+#' @param geom.spacing Defines the space between the dots and error bars of the plotted fitted models. Default
 #'          is 0.3.
-#' @param modelColors A vector with colors for representing the odds values (i.e. points and error bars)
+#' @param geom.colors A vector with colors for representing the odds ratio values (i.e. points and error bars)
 #'          of the different fitted models. Thus, the length of this vector must be equal to
 #'          the length of supplied fitted models, so each model is represented by its own color.
 #'          You can use:
 #'          \itemize{
-#'            \item \code{"bw"} or \code{"black"} for only one colouring in almost black
-#'            \item \code{"gray"}, \code{"grey"} or \code{"gs"} for a grayscale
-#'            \item \code{"brewer"} for colours from the color brewer palette.
+#'            \item If not specified, the qualitative \code{"Dark2"} color brewer palette will be used.
+#'            \item If \code{"gs"}, a greyscale will be used.
+#'            \item If \code{geom.colors} is any valid color brewer palette name, the related \href{http://colorbrewer2.org}{color brewer} palette will be used. Use \code{display.brewer.all()} from the \code{RColorBrewer} package to view all available palette names.
 #'            }
-#'          If \code{modelColors} is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the \url{http://colorbrewer2.org}
-#'          Else specify your own color values as vector (e.g. \code{modelColors=c("#f00000", "#00ff00")}).
-#' @param colorPalette If parameter \code{modelColors} is \code{brewer}, specify a color palette from the \url{http://colorbrewer2.org} here.
-#'          All color brewer palettes supported by ggplot are accepted here.
-#' @param axisLabelColor Colour of the tick labels at the axis (variable names, odds names).
-#' @param valueLabelColor The colour of the odds values. These values are printed above the plots respectively beside the
-#'          bar charts. default color is \code{"black"}.
-#' @param valueLabelSize Size of the value labels. Drfault is 4. Recommended Values range from
-#'          2 to 8
-#' @param valueLabelAlpha The alpha level (transparancy) of the value labels. Default is 1, use
-#'          any value from 0 to 1.
+#'          Else specify your own color values as vector (e.g. \code{geom.colors=c("#f00000", "#00ff00", "#0080ff")}).
 #' @param nsAlpha The alpha level (transparancy) of non significant predicors. Points and error bars
 #'          are affected by this value and plotted with a slight transparancy. Default is 1.
 #' @param usePShapes If \code{TRUE}, significant levels are distinguished by different point shapes and a related
 #'          legend is plotted. Default is \code{FALSE}.
-#' @param axisColor User defined color of axis border (y- and x-axis, in case the axes should have different colors than
-#'          the diagram border).
-#' @param borderColor User defined color of whole diagram border (panel border).
 #' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
 #' @param interceptLineColor The color of the intercept line. Default value is \code{"grey70"}.
-#' @param errorBarWidth The width of the error bar ends. Default is \code{0}
-#' @param errorBarSize The size (thickness) of the error bars. Default is \code{0.5}
-#' @param errorBarLineType The linetype of error bars. Default is \code{1} (solid line).
-#' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
-#' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
-#' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param theme Specifies the diagram's background theme. Default (parameter \code{NULL}) is a gray 
-#'          background with white grids.
-#'          \itemize{
-#'          \item Use \code{"bw"} for a white background with gray grids
-#'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
-#'          \item \code{"none"} for no borders, grids and ticks or
-#'          \item \code{"themr"} if you are using the \code{ggthemr} package
-#'          }
-#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
-#' @param flipCoordinates If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
+#' @param hideLegend Indicates whether legend (guide) should be shown or not.
+#' @param coord.flip If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
 #'          values are plotted on the x-axis.
-#' @param legendPos The position of the legend, if a legend is drawn. Use \code{"bottom"}, \code{"top"}, \code{"left"}
-#'          or \code{"right"} to position the legend above, below, on the left or right side of the diagram. Right
-#'          positioning is default.
-#' @param legendSize The text size of the legend. Default is 1. Relative size, so recommended values are from 0.3 to
-#'          2.5
-#' @param legendBorderColor Color of the legend's border. Default is \code{"white"}, so no visible border is drawn.
-#' @param legendBackColor Fill color of the legend's background. Default is \code{"white"}, so no visible background is drawn.
 #' @param showIntercept If \code{TRUE}, the intercept of the fitted model is also plotted.
 #'          Default is \code{FALSE}. Please note that due to exp-transformation of
 #'          estimates, the intercept in some cases can not be calculated, thus the
@@ -129,6 +81,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'          Default is 2, i.e. estimators have 2 digits after decimal point.
 #' @param showPValueLabels Whether the significance levels of each coefficient should be appended
 #'          to values or not.
+#' @param facet.grid \code{TRUE} when each model should be plotted as single facet instead of 
+#'          an integrated single graph.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
@@ -150,7 +104,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'               family=binomial(link="logit"))
 #' 
 #' # plot multiple models
-#' sjp.glmm(fitOR1, fitOR2, fitOR3)
+#' sjp.glmm(fitOR1, fitOR2, fitOR3, facet.grid=TRUE)
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.glmm(fitOR1, fitOR2, fitOR3,
@@ -164,58 +118,33 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #' @export
 sjp.glmm <- function(..., 
                     title=NULL,
-                    titleSize=1.3,
-                    titleColor="black",
                     labelDependentVariables=NULL, 
                     legendDepVarTitle="Dependent Variables",
                     legendPValTitle="p-level",
                     stringModel="Model",
                     axisLabels.y=NULL, 
-                    axisLabelSize=1.1,
-                    axisLabelAngle.x=0,
-                    axisLabelAngle.y=0, 
-                    axisLabelColor="gray30", 
                     axisTitle.x="Odds Ratios",
-                    axisTitleSize=1.2,
-                    axisTitleColor=c("#444444"),
                     axisLimits=NULL,
                     breakTitleAt=50, 
-                    breakLabelsAt=12,
+                    breakLabelsAt=25,
                     breakLegendAt=20,
                     gridBreaksAt=0.5,
                     transformTicks=FALSE,
-                    errorBarWidth=0,
-                    errorBarSize=0.5,
-                    errorBarLineType=1,
-                    pointSize=3,
-                    modelPlotSpace=0.4,
-                    colorPalette="Paired",
-                    modelColors=NULL,
-                    valueLabelColor="black",
-                    valueLabelSize=4,
-                    valueLabelAlpha=1,
+                    geom.size=3,
+                    geom.spacing=0.4,
+                    geom.colors="Dark2",
                     nsAlpha=1,
                     usePShapes=FALSE,
-                    axisColor=NULL, 
-                    borderColor=NULL, 
                     interceptLineType=2,
                     interceptLineColor="grey70",
-                    majorGridColor=NULL,
-                    minorGridColor=NULL,
-                    hideGrid.x=FALSE,
-                    hideGrid.y=FALSE,
-                    theme=NULL,
-                    flipCoordinates=TRUE,
-                    legendPos="right",
-                    legendSize=1,
-                    legendBorderColor="white",
-                    legendBackColor="white",
+                    coord.flip=TRUE,
                     showIntercept=FALSE,
                     showAxisLabels.y=TRUE,
-                    showTickMarks=TRUE,
                     showValueLabels=TRUE, 
                     labelDigits=2,
                     showPValueLabels=TRUE,
+                    hideLegend=FALSE,
+                    facet.grid=FALSE,
                     printPlot=TRUE) {
   # --------------------------------------------------------
   # retrieve list of fitted models
@@ -401,91 +330,6 @@ sjp.glmm <- function(...,
   # bars.
   # --------------------------------------------------------
   ticks<-c(seq(lower_lim, upper_lim, by=gridBreaksAt))
-  # since the odds are plotted on a log-scale, the grid bars'
-  # distance shrinks with higher odds values. to provide a visual
-  # proportional distance of the grid bars, we can apply the
-  # exponential-function on the tick marks
-  if (transformTicks) {
-    ticks <- exp(ticks)-1
-    ticks <- round(ticks[which(ticks<=upper_lim)],1)
-  }
-  # --------------------------------------------------------
-  # define bar / line colors
-  # --------------------------------------------------------
-  # check whether modelColors is defined
-  if (is.null(modelColors)) {
-    # define default colours. we use a diverging palette here,
-    # because the different models are not "sequential"
-    barcols <- brewer_pal(type="div", palette="Dark2")(fitlength)
-  }
-  else {
-    # if we have b/w colors, i.e. no differentiation between odds > 1 and < 1,
-    # we simply set both colors for ORs lower and greater than 1 to the same color-value
-    if (modelColors=="bw" || modelColors=="black") {
-      barcols <- rep(c("#333333"), times=fitlength)
-    }
-    # grey-scale colors
-    else if (modelColors=="gray" || modelColors=="grey" || modelColors=="gs") {
-      barcols <- brewer_pal(palette="Greys")(fitlength)
-    }
-    else {
-      # else, use user-colors
-      barcols <- modelColors
-    }
-  }
-  # check whether we have brewer color scale
-  if (!is.null(modelColors) && modelColors=="brewer") {
-    # remember to specify the "colorPalette" if you use "brewer" as "oddsColorss"
-    scalecolors <- scale_colour_brewer(palette=colorPalette, labels=labelDependentVariables)
-  }
-  else {
-    scalecolors <- scale_colour_manual(values=barcols, labels=labelDependentVariables)
-  }
-  # --------------------------------------------------------
-  # Set theme and default grid colours. grid colours
-  # might be adjusted later
-  # --------------------------------------------------------
-  hideGridColor <- c("white")
-  if (is.null(theme)) {
-    ggtheme <- theme_gray()
-    hideGridColor <- c("gray90")
-  }
-  else if (theme=="themr") {
-    ggtheme <- NULL
-  }
-  else if (theme=="bw") {
-    ggtheme <- theme_bw()
-  }
-  else if (theme=="classic") {
-    ggtheme <- theme_classic()
-  }
-  else if (theme=="minimal") {
-    ggtheme <- theme_minimal()
-  }
-  else if (theme=="none") {
-    ggtheme <- theme_minimal()
-    majorGridColor <- c("white")
-    minorGridColor <- c("white")
-    showTickMarks <-FALSE
-  }
-  # --------------------------------------------------------
-  # Set up grid colours
-  # --------------------------------------------------------
-  majorgrid <- NULL
-  minorgrid <- NULL
-  if (!is.null(majorGridColor)) {
-    majorgrid <- element_line(colour=majorGridColor)
-  }
-  if (!is.null(minorGridColor)) {
-    minorgrid <- element_line(colour=minorGridColor)
-  }
-  hidegrid <- element_line(colour=hideGridColor)
-  # --------------------------------------------------------
-  # Set up visibility oftick marks
-  # --------------------------------------------------------
-  if (!showTickMarks && !is.null(ggtheme)) {
-    ggtheme <- ggtheme + theme(axis.ticks = element_blank())
-  }
   if (!showAxisLabels.y) {
     axisLabels.y <- c("")
   }
@@ -509,91 +353,64 @@ sjp.glmm <- function(...,
       # The order of aesthetics matters in terms of ordering the error bars!
       # Using shape before colour would order points according to shapes instead
       # of colour-aes.
-      geom_point(aes(y=OR, x=xpos, colour=grp, shape=shape), size=pointSize, position=position_dodge(-modelPlotSpace)) +
+      geom_point(aes(y=OR, x=xpos, colour=grp, shape=shape), size=geom.size, position=position_dodge(-geom.spacing)) +
       # and use a shape scale, in order to have a legend
       scale_shape_manual(values=c(1,16,17,15), labels=c("n.s.", "*", "**", "***"))
   }
   else {
     plotHeader <- plotHeader +
-      geom_point(size=pointSize, position=position_dodge(-modelPlotSpace))
+      geom_point(size=geom.size, position=position_dodge(-geom.spacing))
   }
   # --------------------------------------------------------
   # continue with errorbars, p-value-label and intercept line
   # --------------------------------------------------------
   plotHeader <- plotHeader +
     # print confidence intervalls (error bars)
-    geom_errorbar(aes(ymin=lower, ymax=upper), position=position_dodge(-modelPlotSpace), width=errorBarWidth, size=errorBarSize, linetype=errorBarLineType) +
+    geom_errorbar(aes(ymin=lower, ymax=upper), width=0, position=position_dodge(-geom.spacing)) +
     # print value labels and p-values
-    geom_text(aes(label=p, y=upper), size=valueLabelSize, position=position_dodge(width=-modelPlotSpace), hjust=-0.1) +
+    geom_text(aes(label=p, y=upper), position=position_dodge(width=-geom.spacing), hjust=-0.1) +
     # Intercept-line
     geom_hline(yintercept=1, linetype=interceptLineType, color=interceptLineColor) +
     labs(title=title, x=NULL, y=axisTitle.x, shape=legendPValTitle, colour=legendDepVarTitle) +
     scale_x_discrete(labels=axisLabels.y) +
-    # logarithmic scale for odds
-    scale_y_log10(limits=c(lower_lim, upper_lim), breaks=ticks, labels=ticks) +
-    # add colour legend to indicate different fitted models
-    scalecolors +
     # use transparancy if requested, but hide legend
     scale_alpha_manual(values=c(nsAlpha,1.0), guide="none")
   # --------------------------------------------------------
-  # apply theme
+  # create pretty breaks for log-scale
   # --------------------------------------------------------
-  if (!is.null(ggtheme)) {
+  if (transformTicks) {
+    # since the odds are plotted on a log-scale, the grid bars'
+    # distance shrinks with higher odds values. to provide a visual
+    # proportional distance of the grid bars, we can apply the
+    # exponential-function on the tick marks
     plotHeader <- plotHeader +
-      ggtheme +
-      # --------------------------------------------------------
-      # set axes text and label position etc.
-      # --------------------------------------------------------
-      theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
-            axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-            axis.text.x = element_text(angle=axisLabelAngle.x),
-            axis.text.y = element_text(angle=axisLabelAngle.y),
-            plot.title = element_text(size=rel(titleSize), colour=titleColor),
-            legend.position = legendPos,
-            legend.text = element_text(size=rel(legendSize)),
-            legend.background = element_rect(colour=legendBorderColor, fill=legendBackColor))
+      scale_y_continuous(trans = "log10",
+                         limits = c(lower_lim, upper_lim), 
+                         breaks = base_breaks(upper_lim),
+                         labels = prettyNum)
+  }
+  else {
+    plotHeader <- plotHeader +
+      # logarithmic scale for odds
+      # logarithmic scale for odds
+      scale_y_log10(limits = c(lower_lim, upper_lim), 
+                    breaks = ticks, 
+                    labels = ticks)
   }
   # --------------------------------------------------------
   # flip coordinates?
   # --------------------------------------------------------
-  if (flipCoordinates)  {
+  if (coord.flip)  {
     plotHeader <- plotHeader +
       coord_flip()
   }
-  # --------------------------------------------------------
-  # set border colors
-  # --------------------------------------------------------
-  if (!is.null(borderColor)) {
-    if (!is.null(theme) && theme=="bw") {
-      plotHeader <- plotHeader + 
-        theme(panel.border = element_rect(colour=borderColor))
-    }
-    else {
-      cat("\nParameter 'borderColor' can only be applied to 'bw' theme.\n")
-    }
-  }
-  if (!is.null(axisColor)) {
-    plotHeader <- plotHeader + 
-      theme(axis.line = element_line(colour=axisColor))
-  }
-  if (!is.null(minorgrid)) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.minor = minorgrid)
-  }
-  if (!is.null(majorgrid)) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major = majorgrid)
-  }
-  if (hideGrid.x) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major.x = hidegrid,
-            panel.grid.minor.x = hidegrid)
-  }
-  if (hideGrid.y) {
-    plotHeader <- plotHeader + 
-      theme(panel.grid.major.y = hidegrid,
-            panel.grid.minor.y = hidegrid)
-  }
+  if (facet.grid) {
+    plotHeader <- plotHeader + facet_grid(.~grp)
+  }  
+  # ---------------------------------------------------------
+  # set geom colors
+  # ---------------------------------------------------------
+  plotHeader <- sj.setGeomColors(plotHeader, geom.colors, length(labelDependentVariables), ifelse(hideLegend==TRUE, FALSE, TRUE), labelDependentVariables)
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
