@@ -5,14 +5,12 @@
 #'                the scatter plot is possible. Furthermore, fitted lines can be added
 #'                for each group as well as for the overall plot.
 #'
-#' @references \itemize{
-#'              \item \url{http://rpubs.com/sjPlot/sjpscatter}
-#'              \item \url{http://strengejacke.wordpress.com/sjplot-r-package/}
-#'              }
+#' @seealso \itemize{
+#'           \item \href{http://www.strengejacke.de/sjPlot/sjp.scatter}{sjPlot manual: sjp.scatter}
+#'           \item \code{\link{sjp.lm1}}
+#'           \item \code{\link{sjp.reglin}}
+#'          }
 #'              
-#' @seealso \code{\link{sjp.lm1}} \cr
-#'          \code{\link{sjp.reglin}}
-#' 
 #' @param x A vector (variable) indicating the x positions.
 #' @param y A vector (variable) indicating the y positions.
 #' @param grp A grouping variable. If not \code{NULL}, the scatter plot will be grouped. See
@@ -20,8 +18,6 @@
 #' @param title Title of the diagram, plotted above the whole diagram panel.
 #'          Use \code{"auto"} to automatically detect variable names that will be used as title
 #'          (see \code{\link{sji.setVariableLabels}}) for details).
-#' @param titleSize The size of the plot title. Default is 1.3.
-#' @param titleColor The color of the plot title. Default is \code{"black"}.
 #' @param legendTitle Title of the diagram's legend.
 #' @param legendLabels Labels for the guide/legend.
 #' @param axisTitle.x A label (title) for the x axis.
@@ -30,35 +26,18 @@
 #' @param axisTitle.y A label (title) for the y axis.
 #'          Use \code{"auto"} to automatically detect variable names that will be used as title
 #'          (see \code{\link{sji.setVariableLabels}}) for details).
-#' @param axisTitleColor The color of the x and y axis labels. Refers to \code{axisTitle.x} and \code{axisTitle.y},
-#'          not to the tick mark or category labels.
-#' @param axisTitleSize The size of the x and y axis labels. Refers to \code{axisTitle.x} and \code{axisTitle.y},
-#'          not to the tick mark or category labels.
-#' @param axisTickMarkSize The size of tick mark values of both x and y axis. Default is 1, recommended values range
-#'          between 0.5 and 3.0
-#' @param axisTickMarkColor User defined color for tick mark values. If not specified, a default mid gray
-#'          color will be used for the labels.
 #' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
 #'          one line and when a line break is inserted into the title.
 #' @param breakLegendTitleAt Wordwrap for diagram legend title. Determines how many chars of the legend's title 
 #'          are displayed in one line and when a line break is inserted.
 #' @param breakLegendLabelsAt Wordwrap for diagram legend labels. Determines how many chars of the legend labels are 
 #'          displayed in one line and when a line break is inserted.
-#' @param pointAlpha The alpha values of scattered points. Useful to better cope with overplotting. Default is 0.5
-#' @param pointSize The size of scattered points.
-#' @param pointColors The color(s) of scattered points. If \code{grp} is not \code{NULL}, groups are indicated
+#' @param geom.size The size of scattered points.
+#' @param geom.colors The color(s) of scattered points. If \code{grp} is not \code{NULL}, groups are indicated
 #'          by different colors, thus a vector with multiple color values has to be supplied. By default,
 #'          the \code{Set1} palette of diverging palette type is chosen (see \url{http://colorbrewer2.org}).
-#' @param legendPos The position of the legend, if a legend is drawn. Use \code{"bottom"}, \code{"top"}, \code{"left"}
-#'          or \code{"right"} to position the legend above, below, on the left or right side of the diagram. Right
-#'          positioning is default.
-#' @param legendSize The text size of the legend. Default is 1. Relative size, so recommended values are from 0.3 to
-#'          2.5
-#' @param legendBorderColor Color of the legend's border. Default is \code{"white"}, so no visible border is drawn.
-#' @param legendBackColor Fill color of the legend's background. Default is \code{"white"}, so no visible background is drawn.
 #' @param showTickMarkLabels.x Whether x axis tick mark labels should be shown or not.
 #' @param showTickMarkLabels.y Whether y axis tick mark labels  should be shown or not.
-#' @param showTickMarks Whether tick marks of axes should be shown or not.
 #' @param showGroupFitLine If \code{TRUE}, a fitted line for each group is drawn. See \code{fitmethod} to change the
 #'          fit method of the fitted lines.
 #' @param showTotalFitLine If \code{TRUE}, a fitted line for the overall scatterplot is drawn. See \code{fitmethod} to change the
@@ -72,7 +51,7 @@
 #'            \item \code{"loess"}
 #'            \item \code{"auto"}
 #'          }
-#'          (see \url{http://docs.ggplot2.org/current/stat_smooth.html} for more details).
+#'          (see \href{http://docs.ggplot2.org/current/stat_smooth.html}{ggplot-docs} for more details).
 #' @param useJitter If \code{TRUE}, points will be jittered (to avoid overplotting).
 #' @param autojitter If \code{TRUE}, points will be jittered according to an overlap-estimation. A matrix of \code{x}
 #'          and \code{y} values is created and the amount of cells (indicating a unique point position) is calculated.
@@ -80,27 +59,10 @@
 #'          overlap, they are automatically jittered.
 #' @param jitterRatio The ratio of tolerated overlapping (see \code{autojitter}). If approximated amount of overlapping 
 #'          points exceed this ration, they are automatically jittered. Default is 0.15. Valid values range between 0 and 1.
-#' @param showRug If \code{TRUE}, a marginal rug plot is displayed in the graph (see \url{http://docs.ggplot2.org/current/geom_rug.html}
+#' @param showRug If \code{TRUE}, a marginal rug plot is displayed in the graph (see \href{http://docs.ggplot2.org/current/geom_rug.html}{ggplot-docs}
 #'          for more details).)
 #' @param hideLegend Indicates whether legend (guide) should be shown or not.
-#' @param borderColor User defined color of whole diagram border (panel border).
-#' @param axisColor User defined color of axis border (y- and x-axis, in case the axes should have different colors than
-#'          the diagram border).
-#' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
-#' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
-#' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default is \code{FALSE}.
-#' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default is \code{FALSE}.
-#' @param theme Specifies the diagram's background theme. Default (parameter \code{NULL}) is a gray 
-#'          background with white grids.
-#'          \itemize{
-#'          \item Use \code{"bw"} for a white background with gray grids
-#'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
-#'          \item \code{"none"} for no borders, grids and ticks or
-#'          \item \code{"themr"} if you are using the \code{ggthemr} package (in such cases, you may use the \code{ggthemr::swatch} function to retrieve theme-colors for the \code{pointColors} parameter)
-#'          }
-#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
-#' @param useFacetGrid \code{TRUE} when each scatter plot group should be plotted as single facet instead of 
+#' @param facet.grid \code{TRUE} when each scatter plot group should be plotted as single facet instead of 
 #'          an integrated single graph. Only applies if \code{grp} is not \code{NULL}. Each category of
 #'          \code{grp} will be plotted in an own facet.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
@@ -138,14 +100,14 @@
 #'             legendLabels=sji.getValueLabels(efc)[['e42dep']],
 #'             axisTitle.x=sji.getVariableLabels(efc)['c160age'],
 #'             axisTitle.y=sji.getVariableLabels(efc)['e17age'],
-#'             showGroupFitLine=TRUE, useFacetGrid=TRUE, showSE=TRUE)
+#'             showGroupFitLine=TRUE, facet.grid=TRUE, showSE=TRUE)
 #' 
 #' # -------------------------------
 #' # auto-detection of labels
 #' # -------------------------------
 #' efc <- sji.setVariableLabels(efc, sji.getVariableLabels(efc))
 #' sjp.scatter(efc$c160age,efc$e17age, efc$e42dep,
-#'             title="auto", axisTitle.x="auto", axisTitle.y="auto")
+#'             title="", axisTitle.x="", axisTitle.y="")
 #' 
 #'   
 #' @importFrom scales brewer_pal
@@ -154,36 +116,18 @@
 sjp.scatter <- function(x,
                         y,
                         grp=NULL,
-                        title=NULL, 
-                        titleSize=1.3,
-                        titleColor="black",
+                        title="", 
                         legendTitle=NULL,
                         legendLabels=NULL,
                         axisTitle.x=NULL,
                         axisTitle.y=NULL,
-                        axisTitleColor="black",
-                        axisTitleSize=1.3,
-                        axisTickMarkSize=1,
-                        axisTickMarkColor="grey50",
                         breakTitleAt=50, 
                         breakLegendTitleAt=20, 
                         breakLegendLabelsAt=20,
-                        pointAlpha=0.5,
-                        pointSize=3,
-                        pointColors=NULL,
-                        legendPos="right",
-                        legendSize=1,
-                        legendBorderColor="white",
-                        legendBackColor="white",
+                        geom.size=3,
+                        geom.colors=NULL,
                         showTickMarkLabels.x=TRUE,
                         showTickMarkLabels.y=TRUE,
-                        showTickMarks=TRUE,
-                        majorGridColor=NULL,
-                        minorGridColor=NULL,
-                        hideGrid.x=FALSE,
-                        hideGrid.y=FALSE,
-                        borderColor=NULL, 
-                        axisColor=NULL, 
                         showGroupFitLine=FALSE,
                         showTotalFitLine=FALSE,
                         showSE=FALSE,
@@ -193,16 +137,16 @@ sjp.scatter <- function(x,
                         jitterRatio=0.15,
                         showRug=FALSE,
                         hideLegend=FALSE,
-                        theme=NULL,
-                        useFacetGrid=FALSE,
+                        facet.grid=FALSE,
                         printPlot=TRUE) {
   # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
   if (is.null(legendLabels) && !is.null(grp)) legendLabels <- autoSetValueLabels(grp)
-  if (!is.null(axisTitle.x) && axisTitle.x=="auto") axisTitle.x <- autoSetVariableLabels(x)
-  if (!is.null(axisTitle.y) && axisTitle.y=="auto") axisTitle.y <- autoSetVariableLabels(y)
-  if (!is.null(title) && title=="auto") {
+  if (is.null(legendTitle)) legendTitle <- autoSetVariableLabels(grp)
+  if (is.null(axisTitle.x)) axisTitle.x <- autoSetVariableLabels(x)
+  if (is.null(axisTitle.y)) axisTitle.y <- autoSetVariableLabels(y)
+  if (is.null(title)) {
     t1 <- autoSetVariableLabels(x)
     t2 <- autoSetVariableLabels(y)
     if (!is.null(t1) && !is.null(t2)) {
@@ -213,6 +157,13 @@ sjp.scatter <- function(x,
       }
     }
   }
+  # --------------------------------------------------------
+  # remove titles if empty
+  # --------------------------------------------------------
+  if (!is.null(legendTitle) && legendTitle=="") legendTitle <- NULL
+  if (!is.null(axisTitle.x) && axisTitle.x=="") axisTitle.x <- NULL
+  if (!is.null(axisTitle.y) && axisTitle.y=="") axisTitle.y <- NULL  
+  if (!is.null(title) && title=="") title <- NULL  
   # ------------------------------------------
   # check for auto-jittering
   # ------------------------------------------
@@ -284,67 +235,9 @@ sjp.scatter <- function(x,
     axisTitle.y <- sju.wordwrap(axisTitle.y, breakTitleAt)
   }
   # --------------------------------------------------------
-  # Set theme and default grid colours. grid colours
-  # might be adjusted later
-  # --------------------------------------------------------
-  hideGridColor <- c("white")
-  if (is.null(theme)) {
-    ggtheme <- theme_gray()
-    hideGridColor <- c("gray90")
-  }
-  else if (theme=="themr") {
-    ggtheme <- NULL
-  }
-  else if (theme=="bw") {
-    ggtheme <- theme_bw()
-  }
-  else if (theme=="classic") {
-    ggtheme <- theme_classic()
-  }
-  else if (theme=="minimal") {
-    ggtheme <- theme_minimal()
-  }
-  else if (theme=="none") {
-    ggtheme <- theme_minimal()
-    majorGridColor <- c("white")
-    minorGridColor <- c("white")
-    showTickMarks <-FALSE
-  }
-  # --------------------------------------------------------
-  # Hide or show Tick Marks and Category Labels (x axis text) 
-  # --------------------------------------------------------
-  if (!showTickMarks && !is.null(ggtheme)) {
-    ggtheme <- ggtheme + theme(axis.ticks = element_blank())
-  }
-  # --------------------------------------------------------
-  # Prepare fill colors
-  # --------------------------------------------------------
-  if (is.null(pointColors)) {
-    colen <- length(unique(na.omit(grp)))
-    if (colen==1) {
-      pointColors <- "#003399"
-    }
-    else {
-      pointColors <- brewer_pal(palette="Set1")(colen+1)
-    }
-  }
-  # --------------------------------------------------------
-  # Set up grid colours
-  # --------------------------------------------------------
-  majorgrid <- NULL
-  minorgrid <- NULL
-  if (!is.null(majorGridColor)) {
-    majorgrid <- element_line(colour=majorGridColor)
-  }
-  if (!is.null(minorGridColor)) {
-    minorgrid <- element_line(colour=minorGridColor)
-  }
-  hidegrid <- element_line(colour=hideGridColor)
-  # --------------------------------------------------------
   # Plot scatter plot
   # --------------------------------------------------------
-  scatter <- ggplot(df,aes(x, y, colour=grp)) +
-    scale_color_manual(values=pointColors, labels=legendLabels)
+  scatter <- ggplot(df,aes(x, y, colour=grp))
   # --------------------------------------------------------
   # Add marginal rug
   # --------------------------------------------------------
@@ -360,10 +253,10 @@ sjp.scatter <- function(x,
   # Use Jitter/Points
   # --------------------------------------------------------
   if (useJitter) {
-    scatter <- scatter + geom_jitter(alpha=pointAlpha, size=pointSize)
+    scatter <- scatter + geom_jitter(size = geom.size)
   }
   else {
-    scatter <- scatter + geom_point(alpha=pointAlpha, size=pointSize)
+    scatter <- scatter + geom_point(size = geom.size)
   }
   # --------------------------------------------------------
   # Show fitted lines
@@ -380,17 +273,6 @@ sjp.scatter <- function(x,
   scatter <- scatter + 
     labs(title=title, x=axisTitle.x, y=axisTitle.y, colour=legendTitle)
   # --------------------------------------------------------
-  # apply theme
-  # --------------------------------------------------------
-  if (!is.null(ggtheme)) {
-    scatter <- scatter + 
-      ggtheme +
-      # do minor modifications to theme
-      theme(axis.text = element_text(size=rel(axisTickMarkSize), colour=axisTickMarkColor), 
-            axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-            plot.title = element_text(size=rel(titleSize), colour=titleColor))
-  }
-  # --------------------------------------------------------
   # Hide or show tick marks
   # --------------------------------------------------------
   if (!showTickMarkLabels.x) {
@@ -399,60 +281,28 @@ sjp.scatter <- function(x,
   if (!showTickMarkLabels.y) {
     scatter <- scatter + scale_y_continuous(labels=NULL)
   }
-  # --------------------------------------------------------
-  # Hide or show Legend
-  # --------------------------------------------------------
-  if (hideLegend) {
-    # remove guide / legend
-    scatter <- scatter + guides(colour=FALSE)
-  }
-  # --------------------------------------
-  # set position and size of legend
-  # --------------------------------------
-  if (!hideLegend) {
-    scatter <- scatter + 
-      theme(legend.position = legendPos,
-            legend.text = element_text(size=rel(legendSize)),
-            legend.background = element_rect(colour=legendBorderColor, fill=legendBackColor))
-  }
-  # the panel-border-property can only be applied to the bw-theme
-  if (!is.null(borderColor)) {
-    if (!is.null(theme) && theme=="bw") {
-      scatter <- scatter + 
-        theme(panel.border = element_rect(colour=borderColor))
-    }
-    else {
-      cat("\nParameter 'borderColor' can only be applied to 'bw' theme.\n")
-    }
-  }
-  if (!is.null(axisColor)) {
-    scatter <- scatter + 
-      theme(axis.line = element_line(colour=axisColor))
-  }
-  if (!is.null(minorgrid)) {
-    scatter <- scatter + 
-      theme(panel.grid.minor = minorgrid)
-  }
-  if (!is.null(majorgrid)) {
-    scatter <- scatter + 
-      theme(panel.grid.major = majorgrid)
-  }
-  if (hideGrid.x) {
-    scatter <- scatter + 
-      theme(panel.grid.major.x = hidegrid,
-            panel.grid.minor.x = hidegrid)
-  }
-  if (hideGrid.y) {
-    scatter <- scatter + 
-      theme(panel.grid.major.y = hidegrid,
-            panel.grid.minor.y = hidegrid)
-  }
   # --------------------------------------
   # facet plot
   # --------------------------------------
-  if (useFacetGrid){
+  if (facet.grid){
     scatter <- scatter + facet_wrap(~ grp)
   } 
+  # --------------------------------------------------------
+  # Prepare fill colors
+  # --------------------------------------------------------
+  if (is.null(geom.colors)) {
+    colen <- length(unique(na.omit(grp)))
+    if (colen==1) {
+      geom.colors <- "#003399"
+    }
+    else {
+      geom.colors <- "Dark2"
+    }
+  }
+  # ---------------------------------------------------------
+  # set geom colors
+  # ---------------------------------------------------------
+  scatter <- sj.setGeomColors(scatter, geom.colors, length(legendLabels), ifelse(hideLegend==TRUE, FALSE, TRUE), legendLabels)
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
